@@ -15,9 +15,7 @@ sub dispatch {
 __PACKAGE__->load_plugins(
     'Web::FillInFormLite',
     'Web::JSON',
-    'Web::CSRFDefender' => {
-        post_only => 1,
-    },
+    '+<% $module %>::Web::Plugin::Session',
 );
 
 # setup view
@@ -47,12 +45,4 @@ __PACKAGE__->add_trigger(
     },
 );
 
-__PACKAGE__->add_trigger(
-    BEFORE_DISPATCH => sub {
-        my ( $c ) = @_;
-        # ...
-        return;
-    },
-);
-
 1;
